<?php 

namespace Teknisa\CNC\Controllers;

use Zeedhi\Framework\DataSource\DataSet;
use Zeedhi\Framework\DataSource\FilterCriteria;
use Zeedhi\Framework\DataSource\ParameterBag;
use Zeedhi\Framework\DTO;
use Zeedhi\Framework\DTO\Response\Error;
use Zeedhi\Framework\DTO\Response\Message;
use Zeedhi\Framework\DTO\Response;
use Zeedhi\Framework\DTO\Request;

use Teknisa\CNC\Services\Cnc00400ConciliacaoManualService;
use Teknisa\Libs\Util\Environment;

use Teknisa\CNC\Utilities\UtilCNC;

class Cnc00400ConciliacaoManual {
    protected $entityManager;
    protected $dataSourceName = 'cnc00400_conciliacao_manual';
    protected $parameterBagColumns;
    protected $conciliacaoManualService;
    protected $environment;
    
    public function __construct(\Doctrine\ORM\EntityManager $entityManager, ParameterBag $parameterBag, Cnc00400ConciliacaoManualService $conciliacaoManualService, UtilCNC $util, Environment $environment) {
        $this->parameterBag = $parameterBag;
		$this->entityManager = $entityManager;
        $this->conciliacaoManualService = $conciliacaoManualService;
        $this->util = $util;
        $this->environment = $environment;
    }
    
    public function selectConciliacoes (DTO\Request\Filter $request, DTO\Response $response) {
        try {
            $filter = $request->getFilterCriteria()->getConditions();
            $bool   = $this->util->retrieveValidator($filter);
            if ($bool) {

                $params["NRORG"]           = $this->util->getParamValueFromFilter($filter, "NRORG");
                $params["NRESTABELEC"]     = $this->util->getParamValueFromFilter($filter, "NRESTABELEC");
                $params["NRADQUIRENTE"]    = $this->util->getParamValueFromFilter($filter, "NRADQUIRENTE");
                $params["DTVENDA"]         = $this->util->getParamValueFromFilter($filter, "DTVENDA");
                $params["CDNSU"]           = $this->util->getParamValueFromFilter($filter, "CDNSU");
                $params["NRPRODUTOADQ"]    = $this->util->getParamValueFromFilter($filter, "NRPRODUTOADQ");
                $params["STATUS"]          = $this->util->getParamValueFromFilter($filter, "STATUS");
                $params["ISEQUAL"]         = $this->util->getParamValueFromFilter($filter, "isEqual");
                $params["IDVISPRODUTOADQ"] = $this->util->getParamValueFromFilter($filter, "IDVISPRODUTOADQ");

                $params["NRESTABELEC"] = is_array($params["NRESTABELEC"]) ? 
                    $this->util->buildParamValue($params["NRESTABELEC"]) : null;
                $params["NRADQUIRENTE"] = is_array($params["NRADQUIRENTE"]) ? 
                    $this->util->buildParamValue($params["NRADQUIRENTE"]) : null;
                $params["NRPRODUTOADQ"] = is_array($params["NRPRODUTOADQ"]) ?
                    $this->util->buildParamValue($params["NRPRODUTOADQ"]) : null;
                $params["TNRESTABELEC"]  = $params["NRESTABELEC"] ? null : "T";    
                $params["TNRADQUIRENTE"] = $params["NRADQUIRENTE"] ? null : "T";
                $params["TNRPRODUTOADQ"] = $params["NRPRODUTOADQ"] ? null : "T";
                $params["TCDNSU"]        = $params["CDNSU"] ? null : "T";
                $params["CDNSU"]         = $params["TCDNSU"] ? null : $params["CDNSU"];
                $params["TSTATUS"]       = $params["STATUS"] === "T" ? "T" : null;
                $params["STATUS"]        = $params["TSTATUS"] ? null : $params["STATUS"];
                $dataSets = $this->conciliacaoManualService->selectConciliacoes($params);
                $response->addDataSet(new DataSet("cnc00400_conciliacao_manual", $dataSets));
            }
        } catch (\Exception $e) {
            $response->setError(new Error($e->getMessage(), $e->getCode()));
        }
    }
    
    public function tabAdqFind (DTO\Request\Filter $request, DTO\Response $response) {
        try {
            $filter = $request->getFilterCriteria()->getConditions();
            $params["NRORG"]           = $this->util->getParamValueFromFilter($filter, "NRORG");
            $params["NRESTABELEC"]     = $this->util->getParamValueFromFilter($filter, "NMESTABELEC");
            $params["NRADQUIRENTE"]    = $this->util->getParamValueFromFilter($filter, "NMADQUIRENTE");
            $params["DTVENDA"]         = $this->util->getParamValueFromFilter($filter, "DTVENDA");
            $params["CDNSU"]           = $this->util->getParamValueFromFilter($filter, "NSU");
            $params["NRPRODUTOADQ"]    = $this->util->getParamValueFromFilter($filter, "NMPRODUTOADQ");
            $params["STATUS"]          = $this->util->getParamValueFromFilter($filter, "STATUS");
            $params["ISEQUAL"]         = $this->util->getParamValueFromFilter($filter, "isEqual");
            $params["IDVISPRODUTOADQ"] = $this->util->getParamValueFromFilter($filter, "IDVISPRODUTOADQ");
            
            $params["NRESTABELEC"] = is_array($params["NRESTABELEC"]) && !empty($params["NRESTABELEC"]) ? 
                    $this->util->buildParamValue($params["NRESTABELEC"]) : null;
            $params["NRADQUIRENTE"] = is_array($params["NRADQUIRENTE"]) && !empty($params["NRADQUIRENTE"]) ? 
                $this->util->buildParamValue($params["NRADQUIRENTE"]) : null;
            $params["NRPRODUTOADQ"] = is_array($params["NRPRODUTOADQ"]) && !empty($params["NRPRODUTOADQ"]) ? 
                $this->util->buildParamValue($params["NRPRODUTOADQ"]) : null;

            $params["TNRESTABELEC"]  = $params["NRESTABELEC"] ? null : "T";    
            $params["TNRADQUIRENTE"] = $params["NRADQUIRENTE"] ? null : "T";
            $params["TNRPRODUTOADQ"] = $params["NRPRODUTOADQ"] ? null : "T";
            $params["TCDNSU"]        = $params["CDNSU"] ? null : "T";
            $params["CDNSU"]         = $params["TCDNSU"] ? null : $params["CDNSU"];
            $params["TSTATUS"]       = $params["STATUS"] === "T" ? "T" : null;
            $params["STATUS"]        = $params["TSTATUS"] ? null : $params["STATUS"];
            $dataSets = $this->conciliacaoManualService->selectConciliacoes($params);
            $response->addDataSet(new DataSet('cnc00400_conciliacao_manual_left', $dataSets[0]));
        } catch (\Exception $e) {
            $response->setError(new Error($e->getMessage(), $e->getCode()));
        }
    }
    
    public function tabSisFind (DTO\Request\Filter $request, DTO\Response $response) {
        try {
            $filter = $request->getFilterCriteria()->getConditions();
            $params["NRORG"]           = $this->util->getParamValueFromFilter($filter, "NRORG");
            $params["NRESTABELEC"]     = $this->util->getParamValueFromFilter($filter, "NMESTABELEC");
            $params["NRADQUIRENTE"]    = $this->util->getParamValueFromFilter($filter, "NMADQUIRENTE");
            $params["DTVENDA"]         = $this->util->getParamValueFromFilter($filter, "DTVENDA");
            $params["CDNSU"]           = $this->util->getParamValueFromFilter($filter, "NSU");
            $params["NRPRODUTOADQ"]    = $this->util->getParamValueFromFilter($filter, "NMPRODUTOADQ");
            $params["STATUS"]          = $this->util->getParamValueFromFilter($filter, "STATUS");
            $params["IDVISPRODUTOADQ"] = $this->util->getParamValueFromFilter($filter, "IDVISPRODUTOADQ");
            
            $params["NRESTABELEC"] = is_array($params["NRESTABELEC"]) && !empty($params["NRESTABELEC"]) ? 
                    $this->util->buildParamValue($params["NRESTABELEC"]) : null;
            $params["NRADQUIRENTE"] = is_array($params["NRADQUIRENTE"]) && !empty($params["NRADQUIRENTE"]) ? 
                $this->util->buildParamValue($params["NRADQUIRENTE"]) : null;
            $params["NRPRODUTOADQ"] = is_array($params["NRPRODUTOADQ"]) && !empty($params["NRPRODUTOADQ"]) ? 
                $this->util->buildParamValue($params["NRPRODUTOADQ"]) : null;
            
            $params["TNRESTABELEC"]  = $params["NRESTABELEC"] ? null : "T";      
            $params["TNRADQUIRENTE"] = $params["NRADQUIRENTE"] ? null : "T";
            $params["TNRPRODUTOADQ"] = $params["NRPRODUTOADQ"] ? null : "T";
            $params["TCDNSU"]        = $params["CDNSU"] ? null : "T";
            $params["CDNSU"]         = $params["TCDNSU"] ? null : $params["CDNSU"];
            $params["TSTATUS"]       = $params["STATUS"] === "T" ? "T" : null;
            $params["STATUS"]        = $params["TSTATUS"] ? null : $params["STATUS"];
            $dataSets = $this->conciliacaoManualService->selectConciliacoes($params);
            $response->addDataSet(new DataSet('cnc00400_tabSis_movimentacoes', $dataSets[1]));
        } catch (\Exception $e) {
            $response->setError(new Error($e->getMessage(), $e->getCode()));
        }
    }
    
    public function tabVndFind (DTO\Request\Filter $request, DTO\Response $response) {
        try {
            $filter = $request->getFilterCriteria()->getConditions();
            
            $filter['NRORG'] = array_filter($filter, function($param) {
                return $param['columnName'] === 'NRORG';
            });
            $filter['NRORG'] = array_shift($filter['NRORG']);
            
            $filter['DTVENDA'] = array_filter($filter, function($param) {
                return $param['columnName'] === 'DTVENDA';
            });
            $filter['DTVENDA'] = array_shift($filter['DTVENDA']);
            
            $filter['IDCONCILIADO'] = array_filter($filter, function($param) {
                return $param['columnName'] === 'IDCONCILIADO';
            });
            $filter['IDCONCILIADO'] = array_shift($filter['IDCONCILIADO']);
            
            $filter['NRCONCLANC'] = array_filter($filter, function($param) {
                return $param['columnName'] === 'NRCONCLANC';
            });
            $filter['NRCONCLANC'] = array_shift($filter['NRCONCLANC']);
            
            $filter['NRADQUIRENTE'] = array_filter($filter, function($param) {
                return $param['columnName'] === 'NMADQUIRENTE';
            });
            $filter['NRADQUIRENTE'] = array_shift($filter['NRADQUIRENTE']);
            
            $filter[] = [
                'columnName' => 'ISNULL',
                'operator' => '=',
                'value' => '',
            ];
            $filter['ISNULL'] = array_filter($filter, function($param) {
                return $param['columnName'] === 'ISNULL';
            });
            $filter['ISNULL'] = array_shift($filter['ISNULL']);
            
            $filter['ISNULL']['value'] = $filter['IDCONCILIADO']['value'] === 'C' ? 'N' : 'S';
            
            $dataSet = $this->conciliacaoManualService->selectTabVndMovimentacoes($filter);
            $response->addDataSet(new DataSet('cnc00400_tabAdq_movimentacoes', $dataSet));
        } catch (\Exception $e) {
            $response->setError(new Error($e->getMessage(), $e->getCode()));
        }
    }
    
    public function tabRetFind (DTO\Request\Filter $request, DTO\Response $response) {
        try {
            $filter = $request->getFilterCriteria()->getConditions();
            
            $filter['NRORG'] = array_filter($filter, function($param) {
                return $param['columnName'] === 'NRORG';
            });
            $filter['NRORG'] = array_shift($filter['NRORG']);
            
            $filter['DTVENDA'] = array_filter($filter, function($param) {
                return $param['columnName'] === 'DTVENDA';
            });
            $filter['DTVENDA'] = array_shift($filter['DTVENDA']);
            
            $filter['IDCONCILIADO'] = array_filter($filter, function($param) {
                return $param['columnName'] === 'IDCONCILIADO';
            });
            $filter['IDCONCILIADO'] = array_shift($filter['IDCONCILIADO']);
            
            $filter['NRCONCLANCPGTO'] = array_filter($filter, function($param) {
                return $param['columnName'] === 'NRCONCLANCPGTO';
            });
            $filter['NRCONCLANCPGTO'] = array_shift($filter['NRCONCLANCPGTO']);
            
            $filter['NRADQUIRENTE'] = array_filter($filter, function($param) {
                return $param['columnName'] === 'NMADQUIRENTE';
            });
            $filter['NRADQUIRENTE'] = array_shift($filter['NRADQUIRENTE']);
            
            $filter[] = [
                'columnName' => 'ISNULL',
                'operator' => '=',
                'value' => '',
            ];
            $filter['ISNULL'] = array_filter($filter, function($param) {
                return $param['columnName'] === 'ISNULL';
            });
            $filter['ISNULL'] = array_shift($filter['ISNULL']);
            
            $filter['ISNULL']['value'] = $filter['IDCONCILIADO']['value'] === 'C' ? 'N' : 'S';
            
            $dataSet = $this->conciliacaoManualService->selectTabRetMovimentacoes($filter);
            $response->addDataSet(new DataSet('cnc00400_tabAdq_movimentacoes', $dataSet));
        } catch (\Exception $e) {
            $response->setError(new Error($e->getMessage(), $e->getCode()));
        }
    }
    
    public function desconciliacaoManual (DTO\Request\Row $request, DTO\Response $response) {
        try {
            $rows = $request->getRow();
            $bool = true;
            
            $leftRows  = $rows[0];
            $rightRows = $rows[1];
            $isOneToOne = count($leftRows) == 1 && count($rightRows) == 1;
            if($isOneToOne){
                $NRCONSMOVCAIXA = $rightRows[0]["CHAVE"];
                $NRORG = $this->environment->getNrOrgTrab();
                $this->conciliacaoManualService->deleteItemCorVenda($NRCONSMOVCAIXA, $NRORG);
            }
            
            foreach($leftRows as $row)
                $bool = $bool && $this->conciliacaoManualService->desconciliacaoManualAdq($row);
            foreach($rightRows as $row)
                $bool = $bool && $this->conciliacaoManualService->desconciliacaoManualSis($row);
            
            $response->setStatus($bool);
        } catch (\Exception $e) {
            $response->setError(new Error($e->getMessage(), $e->getCode()));
        }
    }
    
    public function conciliacaoManual (DTO\Request\Row $request, DTO\Response $response) {
        try {
            $connection = $this->entityManager->getConnection();
            $connection->beginTransaction();
            $rows = $request->getRow();
            $bool = true;
            $leftRows  = $rows[0];
            $rightRows = $rows[1];
            $nradquirente["NRADQUIRENTE"] = $leftRows[0]["NRADQUIRENTE"];
            $nrconclanc = intval($this->util->newCode("CONCILIACAOLANC", "20"));
            $date = date("d/m/Y");
            $leftRows[0]["isSolved"] = false;
            $isOneToOne = count($leftRows) == 1 && count($rightRows) == 1;
            
            if($isOneToOne){
                $params["NRCONSMOVCAIXA"] = $rightRows[0]["CHAVE"];
                $params["NRORG"] = $this->environment->getNrOrgTrab();
                $params["NRRETVENDAADQ"] = $leftRows[0]["CHAVE"];
                if($leftRows[0]["NMPRODUTOADQ"] != $rightRows[0]["NMPRODUTOADQ"]){
                    $leftRows[0]["isSolved"] = true;
                    $DSITEMCORRECAO = '%PRODUTO%';
                    $params["NRITEMCORRECAO"] = $this->conciliacaoManualService->checkItemCorrecao($DSITEMCORRECAO)[0]["NRITEMCORRECAO"];
                    $params["NRTPDIVERGENCIA"] = $this->conciliacaoManualService->checkItemDivergencia($DSITEMCORRECAO)[0]["NRTPDIVERGENCIA"];
                    $params["VRANTIGO"] = $rightRows[0]["NMPRODUTOADQ"];
                    $params["VRNOVO"]   = $leftRows[0]["NMPRODUTOADQ"];
                    $this->conciliacaoManualService->insertItemCorVenda($params);
                    $this->conciliacaoManualService->insertDivergenciaConciliacao($params, $nrconclanc);
                }
                if($leftRows[0]["DTVENDA"] != $rightRows[0]["DTVENDA"]){
                    $leftRows[0]["isSolved"] = true;
                    $DSITEMCORRECAO = '%VENDA%';
                    $params["NRITEMCORRECAO"] = $this->conciliacaoManualService->checkItemCorrecao($DSITEMCORRECAO)[0]["NRITEMCORRECAO"];
                    $params["VRANTIGO"] = $rightRows[0]["DTVENDA"];
                    $params["VRNOVO"]   = $leftRows[0]["DTVENDA"];
                    $this->conciliacaoManualService->insertItemCorVenda($params);
                }
                if($leftRows[0]["CDNSU"] != $rightRows[0]["CDNSU"]){
                    $leftRows[0]["isSolved"] = true;
                    $DSITEMCORRECAO = '%NSU%';
                    $params["NRITEMCORRECAO"] = $this->conciliacaoManualService->checkItemCorrecao($DSITEMCORRECAO)[0]["NRITEMCORRECAO"];
                    $params["NRTPDIVERGENCIA"] = $this->conciliacaoManualService->checkItemDivergencia($DSITEMCORRECAO)[0]["NRTPDIVERGENCIA"];
                    $params["VRANTIGO"] = $rightRows[0]["CDNSU"];
                    $params["VRNOVO"]   = $leftRows[0]["CDNSU"];
                    $this->conciliacaoManualService->insertItemCorVenda($params);
                    $this->conciliacaoManualService->insertDivergenciaConciliacao($params, $nrconclanc);
                }
                if($leftRows[0]["NRAUTORIZACAO"] != $rightRows[0]["NRAUTORIZACAO"]){
                    $leftRows[0]["isSolved"] = true;
                    $DSITEMCORRECAO = '%AUTORIZACAO%';
                    $params["NRITEMCORRECAO"] = $this->conciliacaoManualService->checkItemCorrecao($DSITEMCORRECAO)[0]["NRITEMCORRECAO"];
                    $params["NRTPDIVERGENCIA"] = $this->conciliacaoManualService->checkItemDivergencia($DSITEMCORRECAO)[0]["NRTPDIVERGENCIA"];
                    $params["VRANTIGO"] = $rightRows[0]["NRAUTORIZACAO"];
                    $params["VRNOVO"]   = $leftRows[0]["NRAUTORIZACAO"];
                    $this->conciliacaoManualService->insertItemCorVenda($params);
                    $this->conciliacaoManualService->insertDivergenciaConciliacao($params, $nrconclanc);
                }
                if($leftRows[0]["VRBRUTVENDA"] != $rightRows[0]["VRBRUTVENDA"]){
                    $leftRows[0]["isSolved"] = true;
                    $DSITEMCORRECAO = '%VALOR%';
                    $params["NRITEMCORRECAO"] = $this->conciliacaoManualService->checkItemCorrecao($DSITEMCORRECAO)[0]["NRITEMCORRECAO"];
                    $params["VRANTIGO"] = $rightRows[0]["VRBRUTVENDA"];
                    $params["VRNOVO"]   = $leftRows[0]["VRBRUTVENDA"];
                    $this->conciliacaoManualService->insertItemCorVenda($params);
                }
                if($leftRows[0]["DTCREDITO"] != $rightRows[0]["DTCREDITO"]){
                    $leftRows[0]["isSolved"] = true;
                    $DSITEMCORRECAO = '%DATA DE VENCIMENTO%';
                    $params["NRITEMCORRECAO"] = $this->conciliacaoManualService->checkItemCorrecao($DSITEMCORRECAO)[0]["NRITEMCORRECAO"];
                    $params["NRTPDIVERGENCIA"] = $this->conciliacaoManualService->checkItemDivergencia($DSITEMCORRECAO)[0]["NRTPDIVERGENCIA"];
                    $params["VRANTIGO"] = $rightRows[0]["DTCREDITO"];
                    $params["VRNOVO"]   = $leftRows[0]["DTCREDITO"];
                    $this->conciliacaoManualService->insertItemCorVenda($params);
                    $this->conciliacaoManualService->insertDivergenciaConciliacao($params, $nrconclanc);
                }
                
                $bool = $bool && $this->conciliacaoManualService->updateConsWithVnd([$leftRows, $rightRows]);
                $bool = $bool && $this->conciliacaoManualService->insertIntoConciliacao($leftRows, $nrconclanc, $date);
                $bool = $bool && $this->conciliacaoManualService->conciliacaoManualAdq($leftRows, $nrconclanc, $isOneToOne, $rightRows);
                $bool = $bool && $this->conciliacaoManualService->conciliacaoManualSis($rightRows, $nrconclanc, $isOneToOne, $nradquirente, $leftRows);
               
                $paramsPeriodoCont = $this->conciliacaoManualService->verificaEmpresaDataVenda($rightRows[0]);
                $dentroPeriodoContabil = $this->conciliacaoManualService->verificaDataPeriodoContabil($paramsPeriodoCont);
                $vendaDentroCtrlFinanc = $this->conciliacaoManualService->vendaDentroCtrlFinanc($paramsPeriodoCont);

                if($dentroPeriodoContabil && $vendaDentroCtrlFinanc){
                    $bool = $bool && $this->conciliacaoManualService->updateContaReceberNF($rightRows, $nradquirente, $leftRows);
                    $bool = $bool && $this->conciliacaoManualService->recontabilizaVendaConciliada($nrconclanc, $nradquirente); 
                }
            }
            else{
                $bool = $bool && $this->conciliacaoManualService->insertIntoConciliacao($leftRows, $nrconclanc, $date);
                $bool = $bool && $this->conciliacaoManualService->conciliacaoManualAdq($leftRows, $nrconclanc, $isOneToOne, $rightRows);
                //O código abaixo está comentado devido a alterações na rotina para gerar financeiro, onde agora
                // é utilizado informações da tabela CONSMOVCAIXA. Caso futuramente seja necessário realizar a geração financeira
                // pela tabela RETFINANCADQ, a linha abaixo deve ser descomentada.
                
                // $bool = $bool && $this->conciliacaoManualService->processingBeforeSystemConciliation($rightRows);
                
                $bool = $bool && $this->conciliacaoManualService->conciliacaoManualSis($rightRows, $nrconclanc, $isOneToOne, $nradquirente, $leftRows);
                $boletoLancado = self::verifyContReceb($rightRows);
                $vendaDentroCtrlFinanc = $this->conciliacaoManualService->vendaDentroCtrlFinanc($rightRows[0]);
                if ($boletoLancado == 0 && $vendaDentroCtrlFinanc){
                    $bool = $bool && $this->conciliacaoManualService->unificaBoletoPorProduto($rightRows, $leftRows);
                }
                
            }
           
            $connection->commit();

            $response->setStatus($bool);
            
        } catch (\Exception $e) {
            $connection->rollback();
            $response->setError(new Error($e->getMessage(), $e->getCode()));
        }
    }
    
    public function verificaFinanceiroCnc (DTO\Request\Row $request, DTO\Response $response) {
        try {
            $connection = $this->entityManager->getConnection();
            $rows = $request->getRow();
            $bool = true;
            $leftRows  = $rows[0];
            $rightRows = $rows[1];
            $nradquirente["NRADQUIRENTE"] = $leftRows[0]["NRADQUIRENTE"];
            $date = date("d/m/Y");
            $leftRows[0]["isSolved"] = false;
            $isOneToOne = count($leftRows) == 1 && count($rightRows) == 1;
            
            if($isOneToOne){
                $verificaFinanceiro["ONETOONE"] = true;
                $params["NRCONSMOVCAIXA"] = $rightRows[0]["CHAVE"];
                $params["NRORG"] = $this->environment->getNrOrgTrab();
                $params["NRRETVENDAADQ"] = $leftRows[0]["CHAVE"];
             
                $GERAFINANCEIRO = $this->conciliacaoManualService->verificaGeraFinanc($nradquirente)["IDGERAFINANC"];
                if($GERAFINANCEIRO == 'S'){
                    $verificaFinanceiro["GERAFINANCEIRO"] = true;
                    $paramsPeriodoCont = $this->conciliacaoManualService->verificaEmpresaDataVenda($rightRows[0]);
                    $dentroPeriodoContabil = $this->conciliacaoManualService->verificaDataPeriodoContabil($paramsPeriodoCont);
                    if($dentroPeriodoContabil){
                        $verificaFinanceiro["PERIODOCONTABIL"] = true;    
                    }else{
                        $verificaFinanceiro["PERIODOCONTABIL"] = false;
                    }
                }else{
                    $verificaFinanceiro["GERAFINANCEIRO"] = false;
                }
            }else{
                $verificaFinanceiro["ONETOONE"] = false;
            }
            $boletoLancado = self::verifyContReceb($rightRows);
            if($boletoLancado > 0){
                $verificaFinanceiro["BOLETO"] = true;
            }else{
                $verificaFinanceiro["BOLETO"] = false;
            }
            $response->setStatus($bool);
            $response->addDataSet(new \Zeedhi\Framework\DataSource\DataSet('ConciliacaoManualFinanceiro', $verificaFinanceiro));
            
        } catch (\Exception $e) {
            $response->setError(new Error($e->getMessage(), $e->getCode()));
        }
    }
    
    public function verifyContReceb($rightRows){
        try{
            foreach($rightRows as $row){
                $contreceb = $this->conciliacaoManualService->verifyContReceb($row)["FLAGBOLETO"];
                if($contreceb){
                    return $contreceb;
                }
            }
            return $contreceb;
        } catch (\Exception $e) {
            return $e->getMessage();
        }
        
    }
    
    public function verificaBoletoBaixadoCnc(DTO\Request\Row $request, DTO\Response $response) {
        try {
            $connection = $this->entityManager->getConnection();
            $rows = $request->getRow();
            $bool = true;
            $leftRows  = $rows[0];
            $rightRows = $rows[1];
            
            $boletoLancado = self::verifyContReceb($rightRows);
            if($boletoLancado > 0){
                $verificaFinanceiro["BOLETO"] = true;
            }else{
                $verificaFinanceiro["BOLETO"] = false;
            }
            $response->setStatus($bool);
            $response->addDataSet(new \Zeedhi\Framework\DataSource\DataSet('ConciliacaoManualFinanceiro', $verificaFinanceiro));
            
        } catch (\Exception $e) {
            $response->setError(new Error($e->getMessage(), $e->getCode()));
        }
    }
    
    public function getErrors(Request\Filter $request, Response $response){
        try {
            $params = $request->getFilterCriteria()->getConditions();
            $resultado = $this->conciliacaoManualService->getErrors($params);
            $response->addDataSet(new \Zeedhi\Framework\DataSource\DataSet('Cnc00400_ManutencaoConciliacaoError', $resultado));
        } catch (\Exception $e) {
            $response->setError(new Error($e->getMessage(), $e->getCode()));
        }
    }
    
    public function deleteErrors(DTO\Request $request, DTO\Response $response) {
        try {
            $row = $request->getDataSet()->getRows();
            $this->conciliacaoManualService->deleteErrors($row);
            
            $message= array($this->salesMessage->getMessage('excluido'));
            $response->addDataSet(new \Zeedhi\Framework\DataSource\DataSet('Cnc00400_ManutencaoConciliacaoError', $message));
        } catch (\Exception $e) {
            $response->addMessage(new Message($e->getMessage()));
        }
    }
}