<?php

namespace Teknisa\CNC\Services;
use Teknisa\Libs\Util\Environment;
use Teknisa\CNC\Utilities\UtilCNC;
use Teknisa\CNC\Factories\Cnc02600ContCorEstabelecimentoFactory;

class Cnc02600ContCorEstabelecimentoService {
    protected $entityManager;
    protected $factory;
    protected $environment;
    protected $util;
    
    public function __construct (\Doctrine\ORM\EntityManager $entityManager, Environment $environment, Cnc02600ContCorEstabelecimentoFactory $factory, UtilCNC $util) {
        $this->entityManager = $entityManager;
        $this->environment = $environment;
        $this->factory = $factory;
        $this->util = $util;
    }

    public function getEstabelecParam ($params) {
        if(isset($params[1])) {
            $LABELESTABELEC = $params[1]["value"][0]['_ALL'];
        } else {
            $LABELESTABELEC = '%%';
        }
    
        $result = $this->factory->getEstabelecParam(array(
            ':NRORG' => $this->environment->getNrOrgTrab(),
            ':LABELESTABELEC' => $LABELESTABELEC
        ));
        
        return $result;
    }

    public function getEstabelecParamRow ($NRESTABELEC) {
        $result = $this->factory->getEstabelecParamRow(array(
            ':NRORG' => $this->environment->getNrOrgTrab(),
            ':NRESTABELEC' => $NRESTABELEC
        ));
        
        return $result;
    }
    
    public function getAcquirersAut($row){
		$acquires = $this->factory->getAcquirersAut(array(
            ':LABELADQUIRENTE'    => $row['LABELADQUIRENTE']
        ));
        return $acquires;
	}
    
    public function getAdquirenteParam ($params) {
        if(isset($params[1])){
            $LABELADQUIRENTE = $params[1]["value"][0]['_ALL'];
            
        } else{
            $LABELADQUIRENTE = '%%';
        }
        $result = $this->factory->getAdquirenteParam(array(
            ':NRORG'           => $this->environment->getNrOrgTrab(),
            ':NRESTABELEC'     => $params[0]['value'],
            ':LABELADQUIRENTE' => $LABELADQUIRENTE
        ));
        
        return $result;
    }

    public function getAdquirenteParamRow ($NRESTABELEC, $NRADQUIRENTE) {
        $result = $this->factory->getAdquirenteParamRow(array(
            ':NRORG' => $this->environment->getNrOrgTrab(),
            ':NRESTABELEC'  => $NRESTABELEC,
            ':NRADQUIRENTE' => $NRADQUIRENTE
        ));
        
        return $result;
    }
    
    public function getProductsAut($row){
		$acquires = $this->factory->getProductsAut(array(
            ':LABELPRODUTOADQ' => $row['LABELPRODUTOADQ']
        ));
        return $acquires;
	}
    
    public function getProdAdqParam ($params) {
        if(isset($params[2])){
            $LABELPRODUTOADQ = $params[2]["value"][0]['_ALL'];
            
        } else{
            $LABELPRODUTOADQ = '%%';
        }
        $result = $this->factory->getProdAdqParam(array(
            ':NRORG' => $this->environment->getNrOrgTrab(),
            ':NRESTABELEC'     => $params[0]['value'],
            ':NRADQUIRENTE'    => $params[1]['value'],
            ':LABELPRODUTOADQ' => $LABELPRODUTOADQ
        ));
        
        return $result;
    }

    public function getProdutoAdqParamRow ($NRESTABELEC, $NRADQUIRENTE, $NRPRODUTOADQ) {
        $result = $this->factory->getProdutoAdqParamRow(array(
            ':NRORG' => $this->environment->getNrOrgTrab(),
            ':NRESTABELEC'  => $NRESTABELEC,
            ':NRADQUIRENTE' => $NRADQUIRENTE,
            ':NRPRODUTOADQ' => $NRPRODUTOADQ
        ));
        
        return $result;
    }

    public function getAgencias ($row) {
        $result = $this->factory->getAgencias(array(
            ':CDBANCO'   => $row[0]['value'],
            ':CDEMPRESA' => $row[1]['value'],
            ':NRORG'     => $this->environment->getNrOrgTrab()
        ));
        
        return $result;
    }
    
    public function getContas ($row) {
        $result = $this->factory->getContas(array(
            ':CDBANCO'      => $row[0]['value'],
            ':CDAGENCIA'    => $row[1]['value'],
            ':CDEMPRESA'    => $row[2]['value'],
            ':NRORG'        => $this->environment->getNrOrgTrab()
        ));
        
        return $result;
    }

    public function getBancoMasks ($cdbano) {
        $result = $this->factory->getBancoMasks(array(
            ':CDBANCO'  => $cdbano
        ));
        
        return $result;
    }

    public function getEmpresaFilial ($NMFILIAL) {
        $result = $this->factory->getEmpresaFilial(array(
            ':NMFILIAL'  => $NMFILIAL
        ));
        return $result;
    }
    
    public function saveEstabelec ($row) {
        if($row["CDREDUCONT"] == null){
            $arrayCDREDUCONT = $this->factory->getCdreducont(array(
                ":CDBANCO"     => $row["CDBANCO"],
                ":CDAGENCIA"   => preg_replace("/[^0-9]/", "", $row["CDAGENCIA"]),
                ":NRORG"       => $this->environment->getNrOrgTrab(),
                ":CDCONTCORR"  => preg_replace("/[^0-9]/", "", $row["CDCONTCORR"]),
                ":CDEMPRESA"   => $row["CDEMPRESA"]
            ));
            if(count($arrayCDREDUCONT) == 0){
                $row["CDREDUCONT"] = null;
            }else{
                $row["CDREDUCONT"] = $arrayCDREDUCONT[0]["CDREDUCONT"];
            }
        }
        
        $details = $this->getEstabelecParamRow($row["NRESTABELEC"]);
        if(count($details) == 0){
            $row['NRCONTCORESTAB'] = intval($this->util->newCode('CONTCORESTAB', '10'));
            $this->factory->insertContCorEstab(array(
                ":NRORG"            => $this->environment->getNrOrgTrab(),
                ":NRCONTCORESTAB"   => $row['NRCONTCORESTAB'],
                ":NRESTABELEC"      => $row["NRESTABELEC"],
                ":CDREDUCONT"       => $row["CDREDUCONT"],
            ));
        } else{
            $this->factory->updateContCorEstab(array(
                ":NRCONTCORESTAB"   => $row['NRCONTCORESTAB'],
                ":CDREDUCONT"       => $row["CDREDUCONT"]
            ));
        }
    }
    
    public function deleteEstabelecContcor ($params) {
        return $this->factory->deleteEstabelecContcor(array(
            ":NRORG"            => $params["NRORG"],
            ":NRCONTCORESTAB"   => $params["NRCONTCORESTAB"]
        ));
    }
    
    public function saveAdquirente ($row) {
        if($row["CDREDUCONT"] == null){
            $arrayCDREDUCONT = $this->factory->getCdreducont(array(
                ":CDBANCO"     => $row["CDBANCO"],
                ":CDAGENCIA"   => preg_replace("/[^0-9]/", "", $row["CDAGENCIA"]),
                ":NRORG"       => $this->environment->getNrOrgTrab(),
                ":CDCONTCORR"  => preg_replace("/[^0-9]/", "", $row["CDCONTCORR"]),
                ":CDEMPRESA"   => $row["CDEMPRESA"]
            ));
            if(count($arrayCDREDUCONT) == 0){
                $row["CDREDUCONT"] = null;
            }else{
                $row["CDREDUCONT"] = $arrayCDREDUCONT[0]["CDREDUCONT"];
            }
        }
        $details = $this->getAdquirenteParamRow($row["NRESTABELEC"], $row["NRADQUIRENTE"]);
        if(count($details) == 0){
            $row['NRCONTCORESTAB'] = intval($this->util->newCode('CONTCORESTAB', '10'));
            $this->factory->insertContCorAdq(array(
                ":NRORG"            => $this->environment->getNrOrgTrab(),
                ":NRCONTCORESTAB"   => $row['NRCONTCORESTAB'],
                ":NRESTABELEC"      => $row["NRESTABELEC"],
                ":NRADQUIRENTE"     => $row["NRADQUIRENTE"],
                ":CDREDUCONT"       => $row["CDREDUCONT"],
            ));
        } else{
            $this->factory->updateContCorEstab(array(
                ":NRCONTCORESTAB"   => $row['NRCONTCORESTAB'],
                ":CDREDUCONT"       => $row["CDREDUCONT"]
            ));
        }
    }
    
    public function saveProdutoAdq ($row) {
        if($row["CDREDUCONT"] == null){
            $arrayCDREDUCONT = $this->factory->getCdreducont(array(
                ":CDBANCO"     => $row["CDBANCO"],
                ":CDAGENCIA"   => preg_replace("/[^0-9]/", "", $row["CDAGENCIA"]),
                ":NRORG"       => $this->environment->getNrOrgTrab(),
                ":CDCONTCORR"  => preg_replace("/[^0-9]/", "", $row["CDCONTCORR"]),
                ":CDEMPRESA"   => $row["CDEMPRESA"]
            ));
            if(count($arrayCDREDUCONT) == 0){
                $row["CDREDUCONT"] = null;
            }else{
                $row["CDREDUCONT"] = $arrayCDREDUCONT[0]["CDREDUCONT"];
            }
        }
        $details = $this->getProdutoAdqParamRow($row["NRESTABELEC"], $row["NRADQUIRENTE"], $row["NRPRODUTOADQ"]);
        if(count($details) == 0){
            $row['NRCONTCORESTAB'] = intval($this->util->newCode('CONTCORESTAB', '10'));
            $this->factory->insertContCorProd(array(
                ":NRORG"            => $this->environment->getNrOrgTrab(),
                ":NRCONTCORESTAB"   => $row['NRCONTCORESTAB'],
                ":NRESTABELEC"      => $row["NRESTABELEC"],
                ":NRADQUIRENTE"     => $row["NRADQUIRENTE"],
                ":NRPRODUTOADQ"     => $row["NRPRODUTOADQ"],
                ":CDREDUCONT"       => $row["CDREDUCONT"],
            ));
        } else{
            if(!isset($row["NRCONTCORESTAB"])){
                $row["NRCONTCORESTAB"] = $details[0]["NRCONTCORESTAB"];
            }
            $this->factory->updateContCorEstab(array(
                ":NRCONTCORESTAB"   => $row['NRCONTCORESTAB'],
                ":CDREDUCONT"       => $row["CDREDUCONT"]
            ));
        }
    }

}
